This repository holds the [Scalene](https://github.com/plasma-umass/scalene) GUI.

[![Scalene web GUI](https://raw.githubusercontent.com/plasma-umass/scalene/master/docs/scalene-gui-example.png)](https://raw.githubusercontent.com/plasma-umass/scalene/master/docs/scalene-gui-example-full.png)

To use the interactive demo, go to the [Scalene GUI](https://plasma-umass.org/scalene-gui/) site.

# Acknowledgements

Scalene's web GUI makes use of the following wonderful systems. Many thanks to their authors.

- [Vega-Lite](https://vega.github.io/vega-lite/) for rendering graphs
- [Prism](https://prismjs.com/) for code highlighting
- [tablesort](https://github.com/tristen/tablesort) for sorting tables by columns

This material is based upon work supported by the National Science
Foundation under Grant No. 1955610. Any opinions, findings, and
conclusions or recommendations expressed in this material are those of
the author(s) and do not necessarily reflect the views of the National
Science Foundation.
